function [Th0,Tmax,DataCab,kcab] = CableT0(lengthvector)

%%%  Function Description:
%This function is used to get characteristic information about the cable (stiffness, maximum tension,...)

%%%  Input Variables Description: %%%
% Stiff=Calculation of the stiffness at the beggining of the movement (Ini)
% or close to the maximum tension of the cable (End) -->Ini is the normal method
% h=height at which the cable is anchored in the tower (from the seabed)
% Xo=horizontal distance from the cable anchor in the seabed to the tower
% l=total length of the cable
% D=Diameter of the guy cable (mm)
% sf=safety factor for the cable load: API RP 2SK Safety Factors (1,67)/IACS (International Association of Classification Societies)(1,8)(Intact)
% ...2.7 for operational conditions at IACS
% gr = Grade(specification of the cable): ORQ, 3-1, 3-S or 4-1
% xx=Fixed displacement used to calculate the stiffness of the cable
% 

%%%%%%%
Stiff='Ini'; %End of the displacements allowed (End) or at the beginning of the movement of the cable (Ini) -->Calculation of the stiffness

%%%Force of the guy cable
h=70;
Xo=485; %horizontal distance (485)
l=500;
D=100; % D in mm
sf=2.7; % API RP 2SK Safety Factors (1,67)/IACS (International Association of Classification Societies)(1,8)(Intact)
% 2.7 for operational conditions at IACS
gr = '4-1' ; %Grade(specification of the cable): ORQ, 3-1, 3-S or 4-1
[difference,NodeCable]=min(abs(lengthvector-h)); %Node where the cable has 
% the connection to the tower and difference of this value with the real one.

%Calculating the stiffness considering a fixed displacement (xx=1m)
xx=1;

  if gr == 'ORQ'
   c=21.1;     
 elseif gr == '3-1' 
   c=22.3;
 elseif gr == '3-S'     
   c=24.9;
 elseif gr == '4-1'    
   c=27.4;  
 end

w=0.1875*D^2; % N/m (D in mm)
CBS=c*(44-0.08*D)*D^2;   %%Catalogue breaking strength in N
Tmax=CBS/sf;

Th=1000:10000:Tmax+10000; %10kN of difference between values 
g=l-h.*(1+2*Th./(w*h)).^0.5+(Th./w).*(acosh(1+w*h./Th))-Xo;

Th0=interp1(g,Th,0);

lground=l-h*(1+2*Th0/(w*h))^0.5;
if isnan(Th0)
    error('The initial horizontal tension at the cable is above the maximum admisible tension or the horizontal tension is too low') %Compare also T and Tmax(at the end)
end
if lground<5 %length of cable laying on the ground above 5 meters
    error('You must increase the total length of the guy cable')
end
DataCab=[h Xo l D NodeCable];


if Stiff=='Ini'
%Getting the change of force at the cable in the axis of movement
X=DataCab(2)+xx;
g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
Th1=interp1(g,Th,0);
dTh1=Th0-Th1;
%Getting the change of force at the other 2 cables (120 of separation
%between them)
X=(DataCab(2)^2+xx-DataCab(2)*xx*0.5)^0.5;
g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
Th2=interp1(g,Th,0); 
dTh2=Th0-Th2;

FTh=dTh2-dTh1; %
% FTh=FTh*2;%%For 6 cables instead of 3
kcab=FTh/xx;
end

%%%%%%%%%%%%%%%%%%%
% %Calculating the stiffness considering a fixed displacement close to the
% %maximum tension. It is not recommended.
% if Stiff=='End'
% %Getting the maximum displacement allowed at the cable
% xmaxc=0:0.1:50;
% Thmax=Tmax-w*DataCab(1);
% gf=DataCab(3)-DataCab(1)*(1+2*Thmax/(w*DataCab(1)))^0.5+(Thmax/w)*(acosh(1+w*DataCab(1)/Thmax))-(DataCab(2)+xmaxc);
% xMaxCab=interp1(gf,xmaxc,0);
% 
% 
% %Calculating the stiffness considering a fixed displacement close to the
% %maximum displacement allowed
% xx=xMaxCab-0.5;
% %Getting the change of force at the cable in the axis of movement
% X=DataCab(2)+xx;
% g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
% Th1=interp1(g,Th,0);
% dTh1=Th0-Th1;
% %Getting the change of force at the other 2 cables (120 of separation
% %between them)
% X=(DataCab(2)^2+xx-DataCab(2)*xx*0.5)^0.5;
% g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
% Th2=interp1(g,Th,0); 
% dTh2=Th0-Th2;
% 
% FTh1=dTh2-dTh1; %
% 
% xx=xMaxCab-1;
% %Getting the change of force at the cable in the axis of movement
% X=DataCab(2)+xx;
% g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
% Th1=interp1(g,Th,0);
% dTh1=Th0-Th1;
% %Getting the change of force at the other 2 cables (120 of separation
% %between them)
% X=(DataCab(2)^2+xx-DataCab(2)*xx*0.5)^0.5;
% g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
% Th2=interp1(g,Th,0); 
% dTh2=Th0-Th2;
% 
% FTh2=dTh2-dTh1;
% 
% FTh=FTh1-FTh2;
% kcab=FTh/0.5;
% end
end




