function [Dmax,jDmax,Dtotal]=Checks(wdepth,Cable,DataCab,Tmax,Ground,DF,tF,uf,nelmp,Lmp,nnodeF,E,nnode,...
    leng,Mnode,Vnode,Mdc,Vdc,lengthvectorF,rna,density,Bottom,Vcampled,Mcampled,tf)

%%%  Function Description:
%This function is used to check if the structure satisfy the different
%regulations and guidelines for the structure and for the guy cable (chain)

%%%  Input Variables Description: %%%
% a=10^10; %(intersection of S-N curve with the log(n of cycles) axis)
% m=4; % negative slope of the S-N curve
% TimeOcur=(h)time of ocurrence of the load case selected in DynamicLoad.m
% YearsFLS=design fatigue lifetime of the tower.% 
% DFF=Design Fatigue Factor% 
% hSplash=5; %meters above and below the MSL of the splash zone
% fy=250*10^6; % Yield strength (N/m^2) % Structural steel ASTM A36 steel
%

%S-N curve parameters (no endurance limit)
a=10^10; %(intersection of S-N curve with the log(n of cycles) axis)
m=4; % negative slope of the S-N curve
TimeOcur=2664.8;%(h)time of ocurrence of the load case selected in DynamicLoad.m
YearsFLS=15;

TimeOcur=TimeOcur*60*60;

DFF=1;

hSplash=5; %meters above and below the MSL
[difference,NodeSplashUp]=min(abs(lengthvectorF-(wdepth+hSplash))); 
[difference,NodeSplashDown]=min(abs(lengthvectorF-(wdepth-hSplash)));

lengmp = Lmp/nelmp;

%%% Checks %%%
disp(' ')
%%%%%%%%%%%%%%%% Checking the guy cable tension
if Cable=='Y'
w=0.1875*DataCab(4)^2;
ufcable=uf(:,DataCab(5)*2-1);
xCable=max(abs(ufcable));
Th=1000:10000:Tmax+10000;
X=DataCab(2)+xCable;
g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
Thf=interp1(g,Th,0);
Tf=Thf+w*DataCab(1);
lground=DataCab(3)-DataCab(1)*(1+2*Thf/(w*DataCab(1)))^0.5;
if lground<5 %length of cable laying on the ground above 5 meters
    disp('You must increase the total length of the guy cable because it is not laying on the ground during the simulation')
    pause
end
if Tf>Tmax
    error('The maximum admisible tension at the cable is reached during the simulation')
else
    disp('Nice! The cable strength check is satisfied')
end
end
%%%%%%%%%%%%%%%%%%%

fy=250*10^6; % Yield strength (N/m^2) % Structural steel ASTM A36 steel
Ce=0.3; %Critical elastic buckling coefficient
sf2=1.15; %safety factor for the shear check

%%%%%%%%%%% For all the nodes %%%%%%%%%%%%%%%%%%%
B=false; S=false; Ax=false; BA=false; F=false;
for i=1:nnodeF
%%%%Bending
Z=(DF(i)^3-(DF(i)-2*tF(i))^3)/6;
W=(pi/32)*((DF(i)^4-(DF(i)-2*tF(i))^4)/DF(i));

    if fy*DF(i)/(E*tF(i))<=0.0517
fm=Z*fy/W;
    elseif fy*DF(i)/(E*tF(i))>0.0517 && fy*DF(i)/(E*tF(i))<=0.1034
fm=(1.13-2.58*(fy*DF(i)/(E*tF(i))))*(Z/W)*fy;    
    elseif fy*DF(i)/(E*tF(i))>0.1034 %&& fy*DF(i)/(E*tF(i))<=120*fy/E
 fm=(0.94-0.76*(fy*DF(i)/(E*tF(i))))*(Z/W)*fy;           
    end    
    
    %Safety factor:
fcle=2*Ce*E*tF(i)/DF(i); %characteristic elastic local buckling strength
landac=(fy/fcle)^0.5;

Nsd=rna;
for j=i:nnodeF-1 %counting the weight above the node analyzed
Dmid=(DF(j)+DF(j+1))/2; %considering elements with constant D and t in each element
tmid=(tF(j)+tF(j+1))/2;
Amid=pi/4*(Dmid^2-(Dmid-2*tmid)^2);         %Area in the middle of the element
mass=density*Amid;
if j>=nnodeF-nnode
N1=mass*9.81*leng;
else 
N1=mass*9.81*lengmp; 
end
Nsd=Nsd+N1; %negative if in tension (weight is positive always)
end
A=pi/4*(DF(i)^2-(DF(i)-2*tF(i))^2);

if Bottom=='C' && i==1 && Ground=='N'
    Md=Mdc;
else
Md=max(abs(Mnode(i,:)));
end

sigmacsd=Nsd/A+Md/W;

if fy/fcle<=0.170
    fcl=fy;
elseif fy/fcle>0.170 && fy/fcle<=1.911
    fcl=(1.047-0.274*fy/fcle)*fy;
elseif fy/fcle>1.911
    fcl=fcle;
end %fcl=characteristic local buckling strength

landas=abs(sigmacsd)/fcl*landac;
if landas<0.5
    sf=1.15;
elseif landas>=0.5 && landas<=1
    sf=0.85+0.6*landas;
elseif landas>1
    sf=1.45;
end   
 %%%
 
Mrd=fm*W/sf;
        if Md>Mrd
    disp('Sorry. The Bending moment check is NOT satisfied')
    B=true;
    pause
        end
%Shear check
if Bottom=='C' && i==1 && Ground=='N'
    Vd=Vdc;
else
Vd=max(abs(Vnode(i,:)));
end
Vrd=A*fy/(2*sqrt(3)*sf2);
if Vd>Vrd
    disp('Sorry. The Shear check is NOT satisfied') 
    S=true;
    pause
end

%Axial compression and bending for nodes above seabed
if lengthvectorF(i)>0
I=pi/4*((DF(i)/2)^4-(DF(i)/2-tF(i))^4);
kb=2.1;
rg=(I/A)^0.5;%radius of gyration
landab=kb*lengthvectorF(i)*(fcl/E)^0.5/(pi*rg);
if landab<=1.34
 fc=(1-0.28*landab^2)*fy;
elseif landab>1.34
  fc=0.9*fy/landab^2; 
end  %fc=characteristic axial compressive strength
Ncrd=A*fc/sf;
Nclrd=fcl*A/sf;%design axial local buckling resistance
Ney=pi^2*E*I/(kb*lengthvectorF(i))^2;%Euler buckling strength

ChAcB1=Nsd/Ncrd+1/Mrd*(Md/(1-Nsd/Ney));

ChAcB2=Nsd/Nclrd+Md/Mrd;

if ChAcB1>1 || ChAcB2>1
 disp('Sorry! The Axial compression and bending check is NOT satisfied') 
 Ax=true;
 pause
end
end

%Shear + bending
if Vd/Vrd>=0.4
ChShB=Md/Mrd<=(1.4-Vd/Vrd)^0.5;   
elseif Vd/Vrd<0.4
ChShB=Md/Mrd<=1;    
end
if ChShB==false
   disp('Sorry! The interaction of shear and bending moment is NOT satisfied') 
   BA=true;
   pause
end
end

if B==false
disp('Nice! The Bending moment check is satisfied')
end
if S==false
disp('Nice! The Shear check is satisfied')
end
if Ax==false
disp('Nice! The Axial compression and bending check is satisfied')
end
if BA==false
disp('Nice! The interaction of shear and bending moment is satisfied')
end

%%%%%%%%% Fatigue for each element %%%%%%%%% the last one to save time if others don't fulfill the requirements
%Rainflow counting and Palmgren-Miner rule
Dmax=0;
jDmax=0;
Dtotal=zeros(nnodeF,1);
for i=1:nnodeF
    if i<=NodeSplashUp && i>=NodeSplashDown
     FF=10;    %Design fatigue factor for the number of cycles counted
    elseif i<=nelmp
     FF=10;
    elseif i>NodeSplashUp
     FF=2;
    else
     FF=3;
    end       
    
if Bottom=='C' && i==1 && Ground=='N'
   Mn=Mcampled;
   Vn=Vcampled;
else
   Mn=Mnode(i,:);
   Vn=Vnode(i,:);
end
I=pi/4*((DF(i)/2)^4-(DF(i)/2-tF(i))^4);
A=pi/4*(DF(i)^2-(DF(i)-2*tF(i))^2);

% stress=Vn/A;
stress=(DF(i)/2)/I*Mn;%%%%%%%%%%%%%%%%%%%%%%

% figure;
% plot(0:0.1:100,stress)
stress1=sig2ext(stress);
rf=rainflow(stress1);
% figure, rfhist(rf,30,'ampl')
% figure, rfhist(rf,30,'mean')
% figure, rfmatrix(rf,30,30)
[no,xo]=rfhist(rf,20,'ampl');
StressRange=2*xo; %2*amplitude (not mean value considered)- explained in the report
StressRange=StressRange/10^6;%From N/m2 to MPa
Nf=a./(StressRange).^m; %maximum number of cycles to failure for each stress range
D=no./Nf; %Damage for each stress range
Df=sum(D); %Damage associated to the interval of time analyzed
    if size(D,1)>1 %Correcting mistakes of execution in the first node
    Dtotal(i)=0;
    else
TimeserR=TimeOcur/(tf-120);
Dtotal(i)=FF*Df*TimeserR; %%Damage for 1 year
Dtotal(i)=Dtotal(i)*YearsFLS; %Damage for the years calculated in the FLS
    end  
if Dtotal(i)>Dmax
  Dmax=Dtotal(i); %To keep the value of the node with the maximum damage
  jDmax=i;
end

   
end
if Dmax>1/DFF %A factor can be applied 
disp(['The damage of the structure due to fatigue is above the limit for 15 years of FLS at node: '...
    num2str(jDmax) ' from the bottom of the structure. (' num2str(YearsFLS/Dmax) ') years to failure']) 
F=true;
end
if F==false
disp(['Nice! The years until reaching the collapse by fatigue are: ' num2str(YearsFLS/Dmax)])
disp('Nice! The Fatigue Limit State is satisfied')
end
end

