function [k,m,khh]=beam(E,Dn,tn,leng,iel,density,Beam)

% %%%  Function Description:
%     Stiffness and mass matrices for a beam element of the tower

% G=8.4*10^10; %Shear rigidity modulus of the material (N/m2)
% mu=0.9; %correction factor for shear energy


G=8.4*10^10; %Shear rigidity modulus of the material (N/m2)
mu=0.9;%recommended by Timoshenko for circular cross sections

Dmid=(Dn(iel)+Dn(iel+1))/2; %considering elements with constant D and t in each element
tmid=(tn(iel)+tn(iel+1))/2;

I=pi/4*((Dmid/2)^4-(Dmid/2-tmid)^4);         %Inertia in the middle of the element about one axis
A=pi/4*(Dmid^2-(Dmid-2*tmid)^2);            %Area in the middle of the element

% stiffness matrix
if Beam=='T'
phi=12*E*I/(G*A*leng^2);
elseif Beam=='B'
phi=0;
end 
 c=E*I/((1+phi)*leng^3);
 k=c*[12      6*leng   -12       6*leng;...
      6*leng  (4+phi)*leng^2 -6*leng   (2-phi)*leng^2;...
     -12     -6*leng    12      -6*leng;...
      6*leng  (2-phi)*leng^2 -6*leng   (4+phi)*leng^2];
  
 %Timoshenko stiffness for slender beams 
khh= mu*[G*A/leng      G*A/2   -G*A/leng       G*A/2;...
      G*A/2       G*A*leng/4 -G*A/2         G*A*leng/4;...
     -G*A/leng     -G*A/2    G*A/leng      -G*A/2;...
      G*A/2      G*A*leng/4     -G*A/2      G*A*leng/4];
  
 
% mass matrix        
mass=density*A;
    mm1=mass*leng/420;
    m=mm1*[156      22*leng   54       -13*leng;...
          22*leng  4*leng^2  13*leng  -3*leng^2;...
          54       13*leng   156      -22*leng;...
         -13*leng -3*leng^2 -22*leng   4*leng^2];
  



 

