function ode = myode( t,y,mm,vecf,freq,tf,nnode,A,damp,Th0,Tmax,DataCab,kcab,Cable,...
    rna,vo,aw,kw,wf,wdepth,lengthvector,Dtow,leng,nelmp,DataGr,kmg,lengthvectormp,LaboveG,LbelowG,Ground,Wind,Wave)

%%%  Function Description:
%This function is used to define the ode (ordinary differential equation) along
%the total time selected. It introduces all the forces acting at each time.

%%%  Input Variables Description: %%%
% unfL=design load factor for environmental loads
% favL= design load factor for deformation loads
% gap=phase of the wave. If it is 0, the crest of the wave will be at the tower at t=0
% Cd and Cm =Drag and inertia coefficients, respectively (API).
% maxiter=maximum number of iterations for the calculation of the force due to the acceleration of the tower.
% tolerance=absolute tolerance for the iteration in the calculation of the force due to the acceleration of the tower.
%

%Coefficients of safety for the loads: DNV
unfL=1.3; %environmental loads
favL=1;  %deformation loads

%Wave data
gap=pi; %phase of the wave. If it is 0, the crest of the wave will be at the tower at t=0
Cd=0.65; Cm=1.6; %Drag and inertia coefficients (API)

%Iteration to calculate the influence of the acceleration of the tower
maxiter=10;
tolerance=1e-4;

%%%%%%%%%%%%%%%%%%%%%

%%%Total forces and moments and the ode
ac=@(f) -2*damp*freq*y(2)-(freq^2)*y(1)+(f);
%%% Dynamic loads
%External sinusoidal load (at the top) (EXAMPLE)
% nf=nnode*2-1; %force at the top
% pfreq=0.8;
% gap=0;
% ft=0:0.1:tf;
% fex=1000000*sin(pfreq*ft+gap);
% fex = interp1(ft,fex,t); % Interpolate the data set (ft,f) at time t
% fex = vecf(nf)*fex;
%%%%%%%%%%%%%%%

% %%% Non-linear influence of the ground
if Ground=='Y'
SuwW=9.81; % (kN/m3)Saturated unit weight of water
EfswC=DataGr(5)-SuwW; %(kN/m3) Effective soil weight of Clay
EfswS=DataGr(6)-SuwW; %(kN/m3) Effective soil weight of Sand 

yc=2.5*DataGr(8)*DataGr(1); %(m)
HR=2.5*DataGr(1);
nnodemp=nelmp+1;  % total number of nodes in system of the monopile
lengmp = DataGr(2)/nelmp;% uniform mesh (equal size of elements)
[difference,NodeLayer]=min(abs(lengthvectormp-(DataGr(4)))); 
FGrNoF=0;
for i=1:nnodemp-1
  if i>=NodeLayer
      Ground=LaboveG;
  else
      Ground=LbelowG;
  end
  H=DataGr(2)-lengthvectormp(i);%Depth below soil surface (m)
  if Ground=='Clay'
    if H<HR
    pu=3*DataGr(7)+EfswC/10^3*H*1000+DataGr(9)*DataGr(7)*H*1000/(DataGr(1)*1000); % ultimate resistance (kPa)
    p=pu*1000*[0;0.23;0.33;0.5;0.72;0.72*H/HR;0.72*H/HR]; %(N/m2)
    yg=yc*[0;0.1;0.3;1;3;15;1000];
    else
    pu=9*DataGr(7); %(kPa)
    p=pu*1000*[0;0.23;0.33;0.5;0.72;0.72]; %(N/m2)
    yg=yc*[0;0.1;0.3;1;3;1000];
    end
        if i==1
         p=p*DataGr(1)*lengmp/2; %Force in N
        else
         p=p*DataGr(1)*lengmp;    %Force in N
        end
    %%%Force at this node:
    %Total force
    fGround=interp1(yg,p,abs(vecf(i*2-1)*y(1)));
    fGround=favL*fGround;
    %by the stiffness:
    fGrLin=kmg(i)*abs(vecf(i*2-1)*y(1));
    %No lineal term
    if vecf(i*2-1)*y(1)>0
    FGrNo=fGrLin-fGround;
    else
    FGrNo=fGround-fGrLin;
    end
    FGrNo=vecf(i*2-1)*FGrNo;
  end
if Ground=='Sand'
 pus=(DataGr(10)*H+DataGr(11)*DataGr(1))*EfswS*H;
 pud=DataGr(12)*DataGr(1)*EfswS*H;
 pu=min(pus,pud); %kN/m
 yg=0:0.05:2;
 yg=[yg,100];
 p=1000*DataGr(14)*pu*tanh(DataGr(13)*H/DataGr(14)/pu*yg); %(N/m)
  if i==1
     p=p*lengmp/2; %Force in N
  else
     p=p*lengmp;   %Force in N
  end
   %%%%%%Force at this node
       %Total force
    fGround=interp1(yg,p,abs(vecf(i*2-1)*y(1)));
    fGround=favL*fGround;
    %by the stiffness:
    fGrLin=kmg(i)*abs(vecf(i*2-1)*y(1));
    %No lineal term
    if vecf(i*2-1)*y(1)>0
    FGrNo=fGrLin-fGround;
    else
    FGrNo=fGround-fGrLin;
    end
    FGrNo=vecf(i*2-1)*FGrNo;
end
    FGrNoF=FGrNoF+FGrNo;
end
else
FGrNoF=0;    
end


%%%%%%%%%%%%%%%%%%Force of the guy cable
if Cable=='Y'
w=0.1875*DataCab(4)^2;
Th=1000:10000:Tmax+10000;
%Getting the change of force at the cable in the axis of movement
X=DataCab(2)+vecf(DataCab(5)*2-1)*y(1);
g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
Th1=interp1(g,Th,0);
dTh1=Th0-Th1;
%Getting the change of force at the other 2 cables (120 of separation
%between them)
X=(DataCab(2)^2+(vecf(DataCab(5)*2-1)*y(1))^2-DataCab(2)*vecf(DataCab(5)*2-1)*y(1)*0.5)^0.5;
g=DataCab(3)-DataCab(1).*(1+2*Th./(w*DataCab(1))).^0.5+(Th./w).*(acosh(1+w*DataCab(1)./Th))-X;
Th2=interp1(g,Th,0); 
dTh2=Th0-Th2;

fTh=abs(dTh1-dTh2); %Total force in the tower
% fTh=fTh*2;%% for 6 cables
fTh=favL*fTh;
if isnan(fTh)
    fTh=0;
end
fThstiff=kcab*abs(vecf(DataCab(5)*2-1)*y(1));%due to the stiffness
    %No lineal term
    if vecf(DataCab(5)*2-1)*y(1)>0
    FThF=fThstiff-fTh;
    else
    FThF=fTh-fThstiff;
    end
    FThF=vecf(DataCab(5)*2-1)*FThF;
else
    FThF=0;
end

%%%Bending due to the displacement at the top
nf=nnode*2; %moment at the top
Mex=rna*9.81*(vecf(nf-1)*y(1)); %depends on the displacement at the top (cg is not in the center but it is included in the ASHES simulation)
Mex=vecf(nf)*Mex;
Mex=unfL*Mex;

%%%%%Include force from the wind in the RNA (ASHES)+relative movement
if Wind=='Y'
%%Thrust force
nf=nnode*2-1;
Frna=interp1(A(:,1),A(:,2),t);
Frna=Frna*(1-2*vecf(nf)*y(2)/vo+(vecf(nf)*y(2))^2/vo^2); %including relative velocity of the tower
Frna=vecf(nf)*Frna;
Frna=unfL*Frna;
%%Bending moment
nf=nnode*2;
Mrna=interp1(A(:,1),A(:,3),t);
Mrna=vecf(nf)*Mrna;
Mrna=unfL*Mrna;
else
 Frna=0;
 Mrna=0;
end


%%%%Wave load
if Wave=='Y'
z=aw*cos(-wf*t+gap);
zmax=wdepth+z;
[difference,NodeWaveTop]=min(abs(lengthvector-zmax));
vecfwave=vecf((nelmp+1)*2-1:2:NodeWaveTop*2-1,:); %(nelmp+1) from the node of the seabed
NodestoSeabed=NodeWaveTop-nelmp;
velw=zeros(NodestoSeabed,1);%%%  
acelw=zeros(NodestoSeabed,1);
Fwave=zeros(NodestoSeabed,1);
velw(NodestoSeabed)=aw*9.81*kw/wf*cosh(kw*wdepth+kw*z)/cosh(kw*wdepth)*cos(-wf*t+gap); % k*x = 0 -> analyzing just the point on the tower
acelw(NodestoSeabed)=aw*9.81*kw*cosh(kw*wdepth+kw*z)/cosh(kw*wdepth)*sin(-wf*t+gap);
Fwave(NodestoSeabed)=pi/4*Dtow(NodeWaveTop)^2*1025*Cm*acelw(NodestoSeabed)+...      %Inertia force without the acceleration of the tower (included later)
1025/2*Dtow(NodeWaveTop)*Cd*(velw(NodestoSeabed)-vecfwave(NodestoSeabed)*y(2))*abs((velw(NodestoSeabed)-vecfwave(NodestoSeabed)*y(2))); %Total drag force
Fwave(NodestoSeabed)=Fwave(NodestoSeabed)*(leng-(lengthvector(NodeWaveTop)+leng/2-zmax)); %just the corresponding part of length at the top
for i=1:NodestoSeabed-1
  velw(i)=aw*9.81*kw/wf*cosh(kw*wdepth+kw*(lengthvector(i+nelmp)-wdepth))/cosh(kw*wdepth)*cos(-wf*t+gap);  
  acelw(i)=aw*9.81*kw*cosh(kw*wdepth+kw*(lengthvector(i+nelmp)-wdepth))/cosh(kw*wdepth)*sin(-wf*t+gap);
%Force of the wave per length
  Fwave(i)=pi/4*Dtow(i+nelmp)^2*1025*Cm*acelw(i)+...      %Inertia force without the acceleration of the tower (included later)
1025/2*Dtow(i+nelmp)*Cd*(velw(i)-vecfwave(i)*y(2))*abs((velw(i)-vecfwave(i)*y(2))); %Total drag force
Fwave(i)=Fwave(i)*leng;
end
Fwave(1)=Fwave(1)/2; %First node with the force divided by the half (influence of the half of the first element)
FwaveFin=vecfwave'*Fwave; %Force coming from all the nodes affected by the wave
FwaveFin=unfL*FwaveFin;
else
FwaveFin=0;
end

%%%Total forces and moments
% f=Mex+Frna+Mrna+FwaveFin+FGrNoF+FThF;
f=Mex+Frna+Mrna+FwaveFin+FGrNoF+FThF;

%iteration to introduce the relative acceleration of the tower
fFin=f;
if Wave=='Y'
Frelw=zeros(NodestoSeabed,1);
nit=0;
err=tolerance+1; % At least 1 loop
while (nit < maxiter && err > tolerance)
nit=nit+1;
for i=1:NodestoSeabed
Frelw(i)=-pi/4*Dtow(i+nelmp)^2*1025*(Cm-1)*vecfwave(i)*ac(fFin); %force depending on the aceleration
if i==NodestoSeabed
Frelw(i)=Frelw(i)*(leng-(lengthvector(i)+leng/2-zmax));
else
Frelw(i)=Frelw(i)*(leng);
end
end
Frelw(1)=Frelw(1)/2;
FrelwFin=vecfwave'*Frelw;
FrelwFin=unfL*FrelwFin;
fn=f+FrelwFin;
err=abs(fn-fFin); % Absolute error
fFin=fn;
end
if nit == maxiter
fFin=f;
% disp(['The force due to the acceleration of the water does not converge in the mode shape of frequency (Hz): ' num2str(freq/(2*pi))])
end

if isnan(fFin)
 error('The displacements are too high during the simulation')   
end
end
ode=[y(2);ac(fFin)]; % Evaluate ODE at time t
end

